@@ -40,7 +40,7 @@ public:
     {
     }
 
-    QList<QAction *> richTextActionList;
+    QVector<QAction *> richTextActionList;
 
     KPIMTextEdit::RichTextComposerControler *composerControler = nullptr;
     KToggleAction *action_align_left = nullptr;
@@ -100,7 +100,7 @@ RichTextComposerActions::~RichTextComposerActions()
     delete d;
 }
 
-QList<QAction *> RichTextComposerActions::richTextActionList() const
+QVector<QAction *> RichTextComposerActions::richTextActionList() const
 {
     return d->richTextActionList;
 }
@@ -498,7 +498,8 @@ void RichTextComposerActions::setActionsEnabled(bool enabled)
     for (QAction *action : qAsConst(d->richTextActionList)) {
         action->setEnabled(enabled);
     }
-    d->action_add_emoticon->setEmojiPlainText(!enabled);
+    //Use all the time emojiunicode
+    //d->action_add_emoticon->setEmojiPlainText(!enabled);
     d->richTextEnabled = enabled;
 }
 
